summaryrefslogtreecommitdiff
path: root/include/xline.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/xline.h')
-rw-r--r--include/xline.h129
1 files changed, 64 insertions, 65 deletions
diff --git a/include/xline.h b/include/xline.h
index 2a49d8b80..bc9739f21 100644
--- a/include/xline.h
+++ b/include/xline.h
@@ -20,10 +20,9 @@
*/
-#ifndef XLINE_H
-#define XLINE_H
+#pragma once
-/** XLine is the base class for ban lines such as G lines and K lines.
+/** XLine is the base class for ban lines such as G-lines and K-lines.
* Modules may derive from this, and their xlines will automatically be
* handled as expected by any protocol modules (e.g. m_spanningtree will
* propogate them using AddLine). The process of translating a type+pattern
@@ -50,8 +49,13 @@ class CoreExport XLine : public classbase
* @param re The reason of the xline
* @param t The line type, should be set by the derived class constructor
*/
- XLine(time_t s_time, long d, std::string src, std::string re, const std::string &t)
- : set_time(s_time), duration(d), source(src), reason(re), type(t)
+ XLine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& t)
+ : set_time(s_time)
+ , duration(d)
+ , source(src)
+ , reason(re)
+ , type(t)
+ , from_config(false)
{
expiry = set_time + duration;
}
@@ -63,7 +67,7 @@ class CoreExport XLine : public classbase
}
/** Change creation time of an xline. Updates expiry
- * to be after the creation time
+ * to be after the creation time.
*/
virtual void SetCreateTime(time_t created)
{
@@ -98,19 +102,19 @@ class CoreExport XLine : public classbase
virtual void Unset() { }
/** Called when the expiry message is to be displayed for the
- * line. Usually a line in the form 'expiring Xline blah, set by...'
+ * line. Usually a line in the form 'expiring X-line blah, set by...'
* see the DisplayExpiry methods of GLine, ELine etc.
*/
- virtual void DisplayExpiry() = 0;
+ virtual void DisplayExpiry();
/** Returns the displayable form of the pattern for this xline,
* e.g. '*\@foo' or '*baz*'. This must always return the full pattern
* in a form which can be used to construct an entire derived xline,
* even if it is stored differently internally (e.g. GLine stores the
- * ident and host parts seperately but will still return ident\@host
- * for its Displayable() method)
+ * ident and host parts separately but will still return ident\@host
+ * for its Displayable() method).
*/
- virtual const char* Displayable() = 0;
+ virtual const std::string& Displayable() = 0;
/** Called when the xline has just been added.
*/
@@ -122,7 +126,7 @@ class CoreExport XLine : public classbase
/** The duration of the ban, or 0 if permenant
*/
- long duration;
+ unsigned long duration;
/** Source of the ban. This can be a servername or an oper nickname
*/
@@ -141,6 +145,9 @@ class CoreExport XLine : public classbase
*/
const std::string type;
+ // Whether this XLine was loaded from the server config.
+ bool from_config;
+
virtual bool IsBurstable();
};
@@ -150,7 +157,7 @@ class CoreExport KLine : public XLine
{
public:
- /** Create a K-Line.
+ /** Create a K-line.
* @param s_time The set time
* @param d The duration of the xline
* @param src The sender of the xline
@@ -158,7 +165,7 @@ class CoreExport KLine : public XLine
* @param ident Ident to match
* @param host Host to match
*/
- KLine(time_t s_time, long d, std::string src, std::string re, std::string ident, std::string host)
+ KLine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& ident, const std::string& host)
: XLine(s_time, d, src, re, "K"), identmask(ident), hostmask(host)
{
matchtext = this->identmask;
@@ -171,17 +178,15 @@ class CoreExport KLine : public XLine
{
}
- virtual bool Matches(User *u);
+ bool Matches(User* u) CXX11_OVERRIDE;
- virtual bool Matches(const std::string &str);
+ bool Matches(const std::string& str) CXX11_OVERRIDE;
- virtual void Apply(User* u);
-
- virtual void DisplayExpiry();
+ void Apply(User* u) CXX11_OVERRIDE;
- virtual const char* Displayable();
+ const std::string& Displayable() CXX11_OVERRIDE;
- virtual bool IsBurstable();
+ bool IsBurstable() CXX11_OVERRIDE;
/** Ident mask (ident part only)
*/
@@ -198,7 +203,7 @@ class CoreExport KLine : public XLine
class CoreExport GLine : public XLine
{
public:
- /** Create a G-Line.
+ /** Create a G-line.
* @param s_time The set time
* @param d The duration of the xline
* @param src The sender of the xline
@@ -206,7 +211,7 @@ class CoreExport GLine : public XLine
* @param ident Ident to match
* @param host Host to match
*/
- GLine(time_t s_time, long d, std::string src, std::string re, std::string ident, std::string host)
+ GLine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& ident, const std::string& host)
: XLine(s_time, d, src, re, "G"), identmask(ident), hostmask(host)
{
matchtext = this->identmask;
@@ -219,15 +224,13 @@ class CoreExport GLine : public XLine
{
}
- virtual bool Matches(User *u);
+ bool Matches(User* u) CXX11_OVERRIDE;
- virtual bool Matches(const std::string &str);
+ bool Matches(const std::string& str) CXX11_OVERRIDE;
- virtual void Apply(User* u);
+ void Apply(User* u) CXX11_OVERRIDE;
- virtual void DisplayExpiry();
-
- virtual const char* Displayable();
+ const std::string& Displayable() CXX11_OVERRIDE;
/** Ident mask (ident part only)
*/
@@ -244,7 +247,7 @@ class CoreExport GLine : public XLine
class CoreExport ELine : public XLine
{
public:
- /** Create an E-Line.
+ /** Create an E-line.
* @param s_time The set time
* @param d The duration of the xline
* @param src The sender of the xline
@@ -252,7 +255,7 @@ class CoreExport ELine : public XLine
* @param ident Ident to match
* @param host Host to match
*/
- ELine(time_t s_time, long d, std::string src, std::string re, std::string ident, std::string host)
+ ELine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& ident, const std::string& host)
: XLine(s_time, d, src, re, "E"), identmask(ident), hostmask(host)
{
matchtext = this->identmask;
@@ -263,17 +266,15 @@ class CoreExport ELine : public XLine
{
}
- virtual bool Matches(User *u);
+ bool Matches(User* u) CXX11_OVERRIDE;
- virtual bool Matches(const std::string &str);
+ bool Matches(const std::string& str) CXX11_OVERRIDE;
- virtual void Unset();
+ void Unset() CXX11_OVERRIDE;
- virtual void DisplayExpiry();
+ void OnAdd() CXX11_OVERRIDE;
- virtual void OnAdd();
-
- virtual const char* Displayable();
+ const std::string& Displayable() CXX11_OVERRIDE;
/** Ident mask (ident part only)
*/
@@ -290,14 +291,14 @@ class CoreExport ELine : public XLine
class CoreExport ZLine : public XLine
{
public:
- /** Create a Z-Line.
+ /** Create a Z-line.
* @param s_time The set time
* @param d The duration of the xline
* @param src The sender of the xline
* @param re The reason of the xline
* @param ip IP to match
*/
- ZLine(time_t s_time, long d, std::string src, std::string re, std::string ip)
+ ZLine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& ip)
: XLine(s_time, d, src, re, "Z"), ipaddr(ip)
{
}
@@ -308,15 +309,13 @@ class CoreExport ZLine : public XLine
{
}
- virtual bool Matches(User *u);
+ bool Matches(User* u) CXX11_OVERRIDE;
- virtual bool Matches(const std::string &str);
+ bool Matches(const std::string& str) CXX11_OVERRIDE;
- virtual void Apply(User* u);
+ void Apply(User* u) CXX11_OVERRIDE;
- virtual void DisplayExpiry();
-
- virtual const char* Displayable();
+ const std::string& Displayable() CXX11_OVERRIDE;
/** IP mask (no ident part)
*/
@@ -328,14 +327,14 @@ class CoreExport ZLine : public XLine
class CoreExport QLine : public XLine
{
public:
- /** Create a G-Line.
+ /** Create a Q-line.
* @param s_time The set time
* @param d The duration of the xline
* @param src The sender of the xline
* @param re The reason of the xline
* @param nickname Nickname to match
*/
- QLine(time_t s_time, long d, std::string src, std::string re, std::string nickname)
+ QLine(time_t s_time, unsigned long d, const std::string& src, const std::string& re, const std::string& nickname)
: XLine(s_time, d, src, re, "Q"), nick(nickname)
{
}
@@ -345,15 +344,13 @@ class CoreExport QLine : public XLine
~QLine()
{
}
- virtual bool Matches(User *u);
+ bool Matches(User* u) CXX11_OVERRIDE;
- virtual bool Matches(const std::string &str);
+ bool Matches(const std::string& str) CXX11_OVERRIDE;
- virtual void Apply(User* u);
+ void Apply(User* u) CXX11_OVERRIDE;
- virtual void DisplayExpiry();
-
- virtual const char* Displayable();
+ const std::string& Displayable() CXX11_OVERRIDE;
/** Nickname mask
*/
@@ -393,7 +390,7 @@ class CoreExport XLineFactory
* @param xline_specific_mask The mask string for the line, specific to the XLine type being created.
* @return A specialized XLine class of the given type for this factory.
*/
- virtual XLine* Generate(time_t set_time, long duration, std::string source, std::string reason, std::string xline_specific_mask) = 0;
+ virtual XLine* Generate(time_t set_time, unsigned long duration, const std::string& source, const std::string& reason, const std::string& xline_specific_mask) = 0;
virtual bool AutoApplyToUserList(XLine* x) { return true; }
@@ -402,7 +399,7 @@ class CoreExport XLineFactory
virtual ~XLineFactory() { }
};
-/** XLineManager is a class used to manage glines, klines, elines, zlines and qlines,
+/** XLineManager is a class used to manage G-lines, K-lines, E-lines, Z-lines and Q-lines,
* or any other line created by a module. It also manages XLineFactory classes which
* can generate a specialized XLine for use by another module.
*/
@@ -439,7 +436,7 @@ class CoreExport XLineManager
*/
IdentHostPair IdentSplit(const std::string &ident_and_host);
- /** Checks what users match e:lines and sets their ban exempt flag accordingly.
+ /** Checks what users match E-lines and sets their ban exempt flag accordingly.
*/
void CheckELines();
@@ -470,16 +467,17 @@ class CoreExport XLineManager
/** Delete an XLine
* @param hostmask The xline-specific string identifying the line, e.g. "*@foo"
* @param type The type of xline
+ * @param reason The xline reason, if it is being removed successfully
* @param user The user removing the line or NULL if its the local server
* @param simulate If this is true, don't actually remove the line, just return
* @return True if the line was deleted successfully
*/
- bool DelLine(const char* hostmask, const std::string &type, User* user, bool simulate = false);
+ bool DelLine(const char* hostmask, const std::string& type, std::string& reason, User* user, bool simulate = false);
/** Registers an xline factory.
* An xline factory is a class which when given a particular xline type,
* will generate a new XLine specialized to that type. For example if you
* pass the XLineFactory that handles glines some data it will return a
* pointer to a GLine, polymorphically represented as XLine. This is used where
* you do not know the full details of the item you wish to create, e.g. in a
* server protocol module like m_spanningtree, when you receive xlines from other
@@ -517,8 +515,9 @@ class CoreExport XLineManager
/** Expire a line given two iterators which identify it in the main map.
* @param container Iterator to the first level of entries the map
* @param item Iterator to the second level of entries in the map
+ * @param silent If true, doesn't send an expiry SNOTICE.
*/
- void ExpireLine(ContainerIter container, LookupIter item);
+ void ExpireLine(ContainerIter container, LookupIter item, bool silent = false);
/** Apply any new lines that are pending to be applied.
* This will only apply lines in the pending_lines list, to save on
@@ -531,10 +530,10 @@ class CoreExport XLineManager
* will be expired and removed before the list is displayed.
* @param type The type of stats to show
* @param numeric The numeric to give to each result line
- * @param user The username making the query
- * @param results The string_list to receive the results
+ * @param stats Stats context
*/
- void InvokeStats(const std::string &type, int numeric, User* user, string_list &results);
-};
+ void InvokeStats(const std::string& type, unsigned int numeric, Stats::Context& stats);
-#endif
+ /** Expire X-lines which were added by the server configuration and have been removed. */
+ void ExpireRemovedConfigLines(const std::string& type, const insp::flat_set<std::string>& configlines);
+};
@@ -470,16 +467,17 @@ class CoreExport XLineManager
* An xline factory is a class which when given a particular xline type,
* will generate a new XLine specialized to that type. For example if you
- * pass the XLineFactory that handles glines some data it will return a
+ * pass the XLineFactory that handles G-lines some data it will return a
* pointer to a GLine, polymorphically represented as XLine. This is used where
* you do not know the full details of the item you wish to create, e.g. in a